@@ -63,12 +63,12 @@ typedef struct
 	int secretmessage;
 	int smoothlight;
 	int smoothscaling;
-	int sndchannels;
 	int soundfix;
 	int soundfull;
 	int soundmono;
 	int translucency;
 	int uncapped;
+	int vsync;
 	int weaponsquat;
 
 	// [crispy] in-game switches and variables
@@ -80,6 +80,7 @@ typedef struct
 	boolean automapoverlay;
 	boolean flashinghom;
 	boolean fliplevels;
+	boolean flipweapons;
 	boolean havee1m10;
 	boolean havemap33;
 	boolean havessg;
@@ -88,6 +89,8 @@ typedef struct
 
 	const char *sdlversion;
 	const char *platform;
+
+	void (*post_rendering_hook) (void);
 } crispy_t;
 
 extern crispy_t *const crispy;
@@ -95,6 +98,14 @@ extern const crispy_t *critical;
 
 extern void CheckCrispySingleplayer (boolean singleplayer);
 
+enum
+{
+    ASPECTRATIO_OFF,
+    ASPECTRATIO_4_3,
+    ASPECTRATIO_16_10,
+    NUM_ASPECTRATIOS,
+};
+
 enum
 {
     BRIGHTMAPS_OFF,
@@ -165,14 +176,6 @@ enum
     NUM_JUMPS
 };
 
-enum
-{
-    SNDCHANNELS_8,
-    SNDCHANNELS_16,
-    SNDCHANNELS_32,
-    NUM_SNDCHANNELS
-};
-
 enum
 {
     TRANSLUCENCY_OFF,
@@ -182,12 +185,4 @@ enum
     NUM_TRANSLUCENCY
 };
 
-enum
-{
-    UNCAPPED_OFF,
-    UNCAPPED_ON,
-    UNCAPPED_VSYNC,
-    NUM_UNCAPPED
-};
-
 #endif
