@@ -617,6 +617,7 @@ P_TryMove
 // the z will be set to the lowest value
 // and false will be returned.
 //
+static sector_t *movingsector;
 boolean P_ThingHeightClip (mobj_t* thing)
 {
     boolean		onfloor;
@@ -634,16 +635,11 @@ boolean P_ThingHeightClip (mobj_t* thing)
 	// walking monsters rise and fall with the floor
 	thing->z = thing->floorz;
 	// [crispy] update player's viewz on sector move
-	if (thing->player)
+	if (thing->player && thing->subsector->sector == movingsector)
 	{
-	    player_t *const player = thing->player;
+	    extern void P_CalcHeight (player_t* player, boolean safe);
 
-	    player->viewz = player->mo->z + player->viewheight;
-
-	    if (player->viewz > player->mo->ceilingz - 4*FRACUNIT)
-	    {
-		player->viewz = player->mo->ceilingz - 4*FRACUNIT;
-	    }
+	    P_CalcHeight (thing->player, true);
 	}
     }
     else
@@ -1586,6 +1582,7 @@ P_ChangeSector
     nofit = false;
     crushchange = crunch;
 	
+    movingsector = sector;
     // re-check heights for all things near the moving sector
     for (x=sector->blockbox[BOXLEFT] ; x<= sector->blockbox[BOXRIGHT] ; x++)
 	for (y=sector->blockbox[BOXBOTTOM];y<= sector->blockbox[BOXTOP] ; y++)
