@@ -68,7 +68,7 @@ P_Thrust
 // P_CalcHeight
 // Calculate the walking / running height adjustment
 //
-void P_CalcHeight (player_t* player) 
+void P_CalcHeight (player_t* player, boolean safe)
 {
     int		angle;
     fixed_t	bob;
@@ -79,6 +79,8 @@ void P_CalcHeight (player_t* player)
     // OPTIMIZE: tablify angle
     // Note: a LUT allows for effects
     //  like a ramp with low health.
+  if (!safe)
+  {
     player->bob =
 	FixedMul (player->mo->momx, player->mo->momx)
 	+ FixedMul (player->mo->momy,player->mo->momy);
@@ -103,6 +105,7 @@ void P_CalcHeight (player_t* player)
 		player->psp_dy_max = 0;
 	}
     }
+  }
 
     if ((player->cheats & CF_NOMOMENTUM) || !onground)
     {
@@ -120,6 +123,8 @@ void P_CalcHeight (player_t* player)
 
     
     // move viewheight
+  if (!safe)
+  {
     if (player->playerstate == PST_LIVE)
     {
 	player->viewheight += player->deltaviewheight;
@@ -144,6 +149,7 @@ void P_CalcHeight (player_t* player)
 		player->deltaviewheight = 1;
 	}
     }
+  }
     player->viewz = player->mo->z + player->viewheight + bob;
 
     if (player->viewz > player->mo->ceilingz-4*FRACUNIT)
@@ -240,7 +246,7 @@ void P_DeathThink (player_t* player)
 
     player->deltaviewheight = 0;
     onground = (player->mo->z <= player->mo->floorz);
-    P_CalcHeight (player);
+    P_CalcHeight (player, false);
 	
     if (player->attacker && player->attacker != player->mo)
     {
@@ -371,7 +377,7 @@ void P_PlayerThink (player_t* player)
     else
 	P_MovePlayer (player);
     
-    P_CalcHeight (player);
+    P_CalcHeight (player, false);
 
     if (player->mo->subsector->sector->special)
 	P_PlayerInSpecialSector (player);
