@@ -329,7 +329,7 @@ void R_GenerateComposite (int texnum)
     // killough 4/9/98: Next, convert multipatched columns into true columns,
     // to fix Medusa bug while still allowing for transparent regions.
 
-    source = malloc(texture->height); // temporary column
+    source = I_Realloc(NULL, texture->height); // temporary column
     for (i = 0; i < texture->width; i++)
     {
 	if (collump[i] == -1) // process only multipatched columns
@@ -518,7 +518,8 @@ void R_GenerateLookup (int texnum)
 	}
 	// I_Error ("R_GenerateLookup: column without a patch");
 	
-	if (patchcount[x] > 1)
+	// [crispy] treat patch-less columns the same as multi-patched
+	if (patchcount[x] > 1 || !patchcount[x])
 	{
 	    // Use the cached block.
 	    // [crispy] moved up here, the rest in this loop
@@ -842,7 +843,9 @@ void R_InitTextures (void)
 	if (!(i&63))
 	    printf (".");
 
-	if (i == 0 || i == texturelump->sumtextures)
+	// [crispy] initialize for the first texture file lump,
+	// skip through empty texture file lumps which do not contain any texture
+	while (texturelump == texturelumps - 1 || i == texturelump->sumtextures)
 	{
 	    // [crispy] start looking in next texture file
 	    texturelump++;
@@ -1117,33 +1120,6 @@ void R_InitColormaps (void)
     lump = W_GetNumForName(DEH_String("COLORMAP"));
     colormaps = W_CacheLumpNum(lump, PU_STATIC);
 
-    // [crispy] intermediate gamma levels
-    if (!gamma2table)
-    {
-	int i;
-
-	gamma2table = malloc(9 * sizeof(*gamma2table));
-
-	// [crispy] 5 original gamma levels
-	for (i = 0; i < 5; i++)
-	{
-		gamma2table[2*i] = (byte *)gammatable[i];
-	}
-
-	// [crispy] 4 intermediate gamma levels
-	for (i = 0; i < 4; i++)
-	{
-		int j;
-
-		gamma2table[2*i+1] = malloc(256 * sizeof(**gamma2table));
-
-		for (j = 0; j < 256; j++)
-		{
-			gamma2table[2*i+1][j] = (gamma2table[2*i][j] + gamma2table[2*i+2][j]) / 2;
-		}
-	}
-    }
-
     // [crispy] initialize color translation and color strings tables
     {
 	byte *playpal = W_CacheLumpName("PLAYPAL", PU_STATIC);
@@ -1153,7 +1129,7 @@ void R_InitColormaps (void)
 	extern byte V_Colorize (byte *playpal, int cr, byte source, boolean keepgray109);
 
 	if (!crstr)
-	    crstr = malloc(CRMAX * sizeof(*crstr));
+	    crstr = I_Realloc(NULL, CRMAX * sizeof(*crstr));
 
 	// [crispy] check for status bar graphics replacements
 	i = W_CheckNumForName(DEH_String("sttnum0")); // [crispy] Status Bar '0'
@@ -1366,6 +1342,9 @@ void R_PrecacheLevel (void)
 	if (!texturepresent[i])
 	    continue;
 
+	// [crispy] precache composite textures
+	R_GenerateComposite(i);
+
 	texture = textures[i];
 	
 	for (j=0 ; j<texture->patchcount ; j++)
