@@ -81,10 +81,6 @@ fixed_t			viewsin;
 
 player_t*		viewplayer;
 
-// [AM] Fractional part of the current tic, in the half-open
-//      range of [0.0, 1.0).  Used for interpolation.
-fixed_t                 fractionaltic;
-
 // 0 = high, 1 = low
 int			detailshift;	
 
@@ -809,8 +805,8 @@ void R_ExecuteSetViewSize (void)
     }
     else
     {
-	scaledviewwidth = (setblocks*32)<<hires;
-	viewheight = ((setblocks*168/10)&~7)<<hires;
+	scaledviewwidth = (setblocks*32)<<crispy->hires;
+	viewheight = ((setblocks*168/10)&~7)<<crispy->hires;
     }
     
     detailshift = setdetail;
@@ -859,7 +855,7 @@ void R_ExecuteSetViewSize (void)
 	const fixed_t num = (viewwidth<<detailshift)/2*FRACUNIT;
 	for (j = 0; j < LOOKDIRS; j++)
 	{
-	dy = ((i-(viewheight/2 + ((j-LOOKDIRMIN) << hires) * (screenblocks < 11 ? screenblocks : 11) / 10))<<FRACBITS)+FRACUNIT/2;
+	dy = ((i-(viewheight/2 + ((j-LOOKDIRMIN) << crispy->hires) * (screenblocks < 11 ? screenblocks : 11) / 10))<<FRACBITS)+FRACUNIT/2;
 	dy = abs(dy);
 	yslopes[j][i] = FixedDiv (num, dy);
 	}
@@ -967,11 +963,6 @@ void R_SetupFrame (player_t* player)
     viewplayer = player;
 
     // [AM] Interpolate the player camera if the feature is enabled.
-
-    // Figure out how far into the current tic we're in as a fixed_t
-    if (crispy->uncapped)
-        fractionaltic = I_GetTimeMS() * TICRATE % 1000 * FRACUNIT / 1000;
-
     if (crispy->uncapped &&
         // Don't interpolate on the first tic of a level,
         // otherwise oldviewz might be garbage.
@@ -980,7 +971,7 @@ void R_SetupFrame (player_t* player)
         // that would necessitate turning it off for a tic.
         player->mo->interp == true &&
         // Don't interpolate during a paused state
-        !paused && (!menuactive || demoplayback || netgame))
+        leveltime > oldleveltime)
     {
         // Interpolate player camera from their old position to their current one.
         viewx = player->mo->oldx + FixedMul(player->mo->x - player->mo->oldx, fractionaltic);
@@ -1011,7 +1002,7 @@ void R_SetupFrame (player_t* player)
 	pitch = -LOOKDIRMIN;
 
     // apply new yslope[] whenever "lookdir", "detailshift" or "screenblocks" change
-    tempCentery = viewheight/2 + (pitch << hires) * (screenblocks < 11 ? screenblocks : 11) / 10;
+    tempCentery = viewheight/2 + (pitch << crispy->hires) * (screenblocks < 11 ? screenblocks : 11) / 10;
     if (centery != tempCentery)
     {
         centery = tempCentery;
