@@ -24,8 +24,8 @@
 
 #define BASEYCENTER                     100
 
-#define MAXWIDTH                        1120
-#define MAXHEIGHT                       832
+//#define MAXWIDTH                        1120
+//#define MAXHEIGHT                       832
 
 #define PI                                      3.141592657
 
@@ -201,7 +201,7 @@ typedef struct
 typedef byte lighttable_t;      // this could be wider for >8 bit display
 
 #define MAXVISPLANES    160*8
-#define MAXOPENINGS             SCREENWIDTH*64*4
+#define MAXOPENINGS             MAXWIDTH*64*4
 
 typedef struct
 {
@@ -211,10 +211,10 @@ typedef struct
     int special;
     int minx, maxx;
     unsigned short pad1;                  // leave pads for [minx-1]/[maxx+1]
-    unsigned short top[SCREENWIDTH];
+    unsigned short top[MAXWIDTH];
     unsigned short pad2;
     unsigned short pad3;
-    unsigned short bottom[SCREENWIDTH];
+    unsigned short bottom[MAXWIDTH];
     unsigned short pad4;
 } visplane_t;
 
@@ -318,7 +318,7 @@ extern player_t *viewplayer;
 extern angle_t clipangle;
 
 extern int viewangletox[FINEANGLES / 2];
-extern angle_t xtoviewangle[SCREENWIDTH + 1];
+extern angle_t xtoviewangle[MAXWIDTH + 1];
 
 extern fixed_t rw_distance;
 extern angle_t rw_normalangle;
@@ -410,11 +410,11 @@ extern int skyflatnum;
 
 extern short openings[MAXOPENINGS], *lastopening;
 
-extern short floorclip[SCREENWIDTH];
-extern short ceilingclip[SCREENWIDTH];
+extern short floorclip[MAXWIDTH];
+extern short ceilingclip[MAXWIDTH];
 
-extern fixed_t yslope[SCREENHEIGHT];
-extern fixed_t distscale[SCREENWIDTH];
+extern fixed_t yslope[MAXHEIGHT];
+extern fixed_t distscale[MAXWIDTH];
 
 void R_InitPlanes(void);
 void R_ClearPlanes(void);
@@ -472,8 +472,8 @@ extern vissprite_t vissprites[MAXVISSPRITES], *vissprite_p;
 extern vissprite_t vsprsortedhead;
 
 // constant arrays used for psprite clipping and initializing clipping
-extern short negonearray[SCREENWIDTH];
-extern short screenheightarray[SCREENWIDTH];
+extern short negonearray[MAXWIDTH];
+extern short screenheightarray[MAXWIDTH];
 
 // vars for R_DrawMaskedColumn
 extern short *mfloorclip;
