@@ -35,7 +35,7 @@ static int always_run = 0;
 
 static int *controls[] = { &key_left, &key_right, &key_up, &key_down,
                            &key_alt_up, &key_alt_down,
-                           &key_reverse, &key_toggleautorun,
+                           &key_reverse, &key_toggleautorun, &key_togglenovert,
                            &key_strafeleft, &key_straferight, &key_fire,
                            &key_alt_strafeleft, &key_alt_straferight,
                            &key_use, &key_strafe, &key_speed, &key_jump,
@@ -223,6 +223,7 @@ static void ConfigExtraKeys(TXT_UNCAST_ARG(widget), TXT_UNCAST_ARG(unused))
         AddKeyControl(table, "Strafe Left (alt.)", &key_alt_strafeleft);
         AddKeyControl(table, "Strafe Right (alt.)", &key_alt_straferight);
         AddKeyControl(table, "Toggle always run", &key_toggleautorun);
+        AddKeyControl(table, "Toggle vert. mouse", &key_togglenovert);
         AddKeyControl(table, "Quick Reverse", &key_reverse);
         }
         else
@@ -393,7 +394,7 @@ static void OtherKeysDialog(TXT_UNCAST_ARG(widget), TXT_UNCAST_ARG(unused))
     TXT_AddWidget(window, scrollpane);
 }
 
-void ConfigKeyboard(void)
+void ConfigKeyboard(TXT_UNCAST_ARG(widget), void *user_data)
 {
     txt_window_t *window;
     txt_checkbox_t *run_control;
