@@ -37,6 +37,7 @@
 #include "v_video.h"
 #include "w_wad.h"
 #include "z_zone.h"
+#include "crispy.h"
 
 #include "config.h"
 #ifdef HAVE_LIBPNG
@@ -94,12 +95,12 @@ void V_CopyRect(int srcx, int srcy, pixel_t *source,
     pixel_t *src;
     pixel_t *dest;
  
-    srcx <<= hires;
-    srcy <<= hires;
-    width <<= hires;
-    height <<= hires;
-    destx <<= hires;
-    desty <<= hires;
+    srcx <<= crispy->hires;
+    srcy <<= crispy->hires;
+    width <<= crispy->hires;
+    height <<= crispy->hires;
+    destx <<= crispy->hires;
+    desty <<= crispy->hires;
 
 #ifdef RANGECHECK 
     if (srcx < 0
@@ -218,28 +219,53 @@ static void V_DrawPatchCrispy(int x, int y, patch_t *patch, int r)
 
     for ( ; col<w << FRACBITS ; x++, col+=dxi, desttop++, desttop2++)
     {
-        int top = -1;
+        int topdelta = -1;
+
+        // [crispy] too far left
+        if (x < 0)
+        {
+            continue;
+        }
+
+        // [crispy] too far right / width
+        if (x >= SCREENWIDTH)
+        {
+            break;
+        }
+
         column = (column_t *)((byte *)patch + LONG(patch->columnofs[col >> FRACBITS]));
 
         // step through the posts in a column
         while (column->topdelta != 0xff)
         {
-            int height, srccol = 0;
+            int top, srccol = 0;
             // [crispy] support for DeePsea tall patches
-            if (column->topdelta <= top)
+            if (column->topdelta <= topdelta)
             {
-                top += column->topdelta;
+                topdelta += column->topdelta;
             }
             else
             {
-                top = column->topdelta;
+                topdelta = column->topdelta;
             }
-            height = ((y + top + column->length) * dy) >> FRACBITS;
+            top = ((y + topdelta) * dy) >> FRACBITS;
             source = (byte *)column + 3;
-            dest = desttop + ((top * dy) >> FRACBITS)*SCREENWIDTH;
-            dest2 = desttop2 + ((top * dy) >> FRACBITS)*SCREENWIDTH;
+            dest = desttop + ((topdelta * dy) >> FRACBITS)*SCREENWIDTH;
+            dest2 = desttop2 + ((topdelta * dy) >> FRACBITS)*SCREENWIDTH;
             count = (column->length * dy) >> FRACBITS;
 
+            // [crispy] too low / height
+            if (top + count > SCREENHEIGHT)
+            {
+                count = SCREENHEIGHT - top;
+            }
+
+            // [crispy] nothing left to draw?
+            if (count < 1)
+            {
+                break;
+            }
+
             while (count--)
             {
                 if (r)
@@ -248,8 +274,8 @@ static void V_DrawPatchCrispy(int x, int y, patch_t *patch, int r)
                     dest2 += SCREENWIDTH;
                 }
 
-                // [crispy] prevent framebuffer overflows
-                if (height > count)
+                // [crispy] too high
+                if (top++ >= 0)
                 {
                     *dest = drawpatchpx(*dest, source[srccol >> FRACBITS]);
                 }
@@ -349,31 +375,56 @@ void V_DrawPatchFlipped(int x, int y, patch_t *patch)
 
     for ( ; col<w << FRACBITS ; x++, col+=dxi, desttop++)
     {
-        int top = -1;
+        int topdelta = -1;
+
+        // [crispy] too far left
+        if (x < 0)
+        {
+            continue;
+        }
+
+        // [crispy] too far right / width
+        if (x >= SCREENWIDTH)
+        {
+            break;
+        }
+
         column = (column_t *)((byte *)patch + LONG(patch->columnofs[w-1-(col >> FRACBITS)]));
 
         // step through the posts in a column
         while (column->topdelta != 0xff )
         {
-            int height, srccol = 0;
+            int top, srccol = 0;
             // [crispy] support for DeePsea tall patches
-            if (column->topdelta <= top)
+            if (column->topdelta <= topdelta)
             {
-                top += column->topdelta;
+                topdelta += column->topdelta;
             }
             else
             {
-                top = column->topdelta;
+                topdelta = column->topdelta;
             }
-            height = ((y + top + column->length) * dy) >> FRACBITS;
+            top = ((y + topdelta) * dy) >> FRACBITS;
             source = (byte *)column + 3;
-            dest = desttop + ((top * dy) >> FRACBITS)*SCREENWIDTH;
+            dest = desttop + ((topdelta * dy) >> FRACBITS)*SCREENWIDTH;
             count = (column->length * dy) >> FRACBITS;
 
+            // [crispy] too low / height
+            if (top + count > SCREENHEIGHT)
+            {
+                count = SCREENHEIGHT - top;
+            }
+
+            // [crispy] nothing left to draw?
+            if (count < 1)
+            {
+                break;
+            }
+
             while (count--)
             {
-                // [crispy] prevent framebuffer overflows
-                if (height > count)
+                // [crispy] too high
+                if (top++ >= 0)
                 {
                     *dest = source[srccol >> FRACBITS];
                 }
@@ -654,7 +705,7 @@ void V_DrawBlock(int x, int y, int width, int height, pixel_t *src)
  
     V_MarkRect (x, y, width, height); 
  
-    dest = dest_screen + (y << hires) * SCREENWIDTH + x;
+    dest = dest_screen + (y << crispy->hires) * SCREENWIDTH + x;
 
     while (height--) 
     { 
@@ -681,13 +732,13 @@ void V_DrawScaledBlock(int x, int y, int width, int height, byte *src)
 
     V_MarkRect (x, y, width, height);
 
-    dest = dest_screen + (y << hires) * SCREENWIDTH + (x << hires);
+    dest = dest_screen + (y << crispy->hires) * SCREENWIDTH + (x << crispy->hires);
 
-    for (i = 0; i < (height << hires); i++)
+    for (i = 0; i < (height << crispy->hires); i++)
     {
-        for (j = 0; j < (width << hires); j++)
+        for (j = 0; j < (width << crispy->hires); j++)
         {
-            *(dest + i * SCREENWIDTH + j) = *(src + (i >> hires) * width + (j >> hires));
+            *(dest + i * SCREENWIDTH + j) = *(src + (i >> crispy->hires) * width + (j >> crispy->hires));
         }
     }
 }
@@ -769,11 +820,11 @@ void V_CopyScaledBuffer(byte *dest, byte *src, size_t size)
 
     while (size--)
     {
-        for (i = 0; i <= hires; i++)
+        for (i = 0; i <= crispy->hires; i++)
         {
-            for (j = 0; j <= hires; j++)
+            for (j = 0; j <= crispy->hires; j++)
             {
-                *(dest + (size << hires) + (hires * (int) (size / ORIGWIDTH) + i) * SCREENWIDTH + j) = *(src + size);
+                *(dest + (size << crispy->hires) + (crispy->hires * (int) (size / ORIGWIDTH) + i) * SCREENWIDTH + j) = *(src + size);
             }
         }
     }
@@ -934,7 +985,7 @@ void WritePNGfile(char *filename, pixel_t *data,
     extern void I_RenderReadPixels(byte **data, int *w, int *h, int *p);
 
 /*
-    if (aspect_ratio_correct)
+    if (aspect_ratio_correct == 1)
     {
         // scale up to accommodate aspect ratio correction
         w_factor = 5;
